==> kubernetes-model-1.0.44-sources.jar: annotations/io/fabric8/openshift/api/model/NamedRoleFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.HasMetadata;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;

public class NamedRoleFluentImpl<T extends NamedRoleFluent<T>> extends BaseFluent<T> implements NamedRoleFluent<T>{

     String name;     VisitableBuilder<Role, ?> role;     Map<String, Object> additionalProperties = new HashMap();
public NamedRoleFluentImpl(){
    
}
public NamedRoleFluentImpl( NamedRole instance ){
    this.withName(instance.getName()); this.withRole(instance.getRole()); 
}

    public String getName(){
    return this.name;
    }
    public T withName( String name){
    this.name=name; return (T) this;
    }
    public Role getRole(){
    return this.role!=null?this.role.build():null;
    }
    public T withRole( Role role){
    if (role!=null){ this.role= new RoleBuilder(role); _visitables.add(this.role);} return (T) this;
    }
    public RoleNested<T> withNewRole(){
    return new RoleNestedImpl<T>();
    }
    public RoleNested<T> withNewRoleLike( Role item){
    return new RoleNestedImpl<T>(item);
    }
    public RoleNested<T> editRole(){
    return withNewRoleLike(getRole());
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
NamedRoleFluentImpl that = (NamedRoleFluentImpl) o;
if (name != null ? !name.equals(that.name) :that.name != null) return false;
if (role != null ? !role.equals(that.role) :that.role != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class RoleNestedImpl<N> extends RoleFluentImpl<RoleNested<N>> implements RoleNested<N>{

        private final RoleBuilder builder;
    
             RoleNestedImpl (){
        this.builder = new RoleBuilder(this);
        }
             RoleNestedImpl ( Role item){
        this.builder = new RoleBuilder(this, item);
        }
    
            public N endRole(){
            return and();
        }
            public N and(){
            return (N) NamedRoleFluentImpl.this.withRole(builder.build());
        }
    
}


}

==> kubernetes-model-1.0.50-sources.jar: annotations/io/fabric8/openshift/api/model/NamedRoleFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.HasMetadata;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;

public class NamedRoleFluentImpl<A extends NamedRoleFluent<A>> extends BaseFluent<A> implements NamedRoleFluent<A>{

     String name;     VisitableBuilder<Role, ?> role;
public NamedRoleFluentImpl(){
    
}
public NamedRoleFluentImpl( NamedRole instance ){
    this.withName(instance.getName()); this.withRole(instance.getRole()); 
}

    public String getName(){
    return this.name;
    }
    public A withName( String name){
    this.name=name; return (A) this;
    }
    public Role getRole(){
    return this.role!=null?this.role.build():null;
    }
    public A withRole( Role role){
    if (role!=null){ this.role= new RoleBuilder(role); _visitables.add(this.role);} return (A) this;
    }
    public RoleNested<A> withNewRole(){
    return new RoleNestedImpl();
    }
    public RoleNested<A> withNewRoleLike( Role item){
    return new RoleNestedImpl(item);
    }
    public RoleNested<A> editRole(){
    return withNewRoleLike(getRole());
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
NamedRoleFluentImpl that = (NamedRoleFluentImpl) o;
if (name != null ? !name.equals(that.name) :that.name != null) return false;
if (role != null ? !role.equals(that.role) :that.role != null) return false;
return true;

    }

    public class RoleNestedImpl<N> extends RoleFluentImpl<RoleNested<N>> implements RoleNested<N>{

        private final RoleBuilder builder;
    
             RoleNestedImpl (){
        this.builder = new RoleBuilder(this);
        }
             RoleNestedImpl ( Role item){
        this.builder = new RoleBuilder(this, item);
        }
    
            public N endRole(){
            return and();
        }
            public N and(){
            return (N) NamedRoleFluentImpl.this.withRole(builder.build());
        }
    
}


}
